package com.zipcodewilmington.phone;

import com.zipcodewilmington.exceptions.InvalidPhoneNumberFormatException;

import java.util.Random;
import java.util.logging.Logger;

/**
 * Created by leon on 5/1/17.
 */
public final class PhoneNumberFactory
{
    private static final Logger logger = Logger.getGlobal();

    private PhoneNumberFactory()
    {
        /** This constructor is private
         *  This class is uninstantiable */
    }

    /**
     * @param phoneNumberCount - number of PhoneNumber objects to instantiate
     * @return array of randomly generated PhoneNumber objects
     */ //TODO - Implement logic
    public static PhoneNumber[] createRandomPhoneNumberArray(int phoneNumberCount)
    {
        PhoneNumber[] phoneNumber =  new PhoneNumber[phoneNumberCount];

        for (int i = 0; i < phoneNumberCount; i++) {
            phoneNumber[i] = createRandomPhoneNumber();
        }

        return phoneNumber;
    }

    /**
     * @return an instance of PhoneNumber with randomly generated phone number value
     */ //TODO - Implement logic
    public static PhoneNumber createRandomPhoneNumber()
    {
         Random r = new Random();

        int areaCode = r.nextInt(900) + 100;

        int centralOfficeCode = r.nextInt(900) + 100;

        int phoneLineCode = r.nextInt(8999) + 1000;

        System.out.println("area Code: " + areaCode + "\tCentral office: " + centralOfficeCode + "\tPhoneLine: " + phoneLineCode);

        return createPhoneNumberSafely(areaCode, centralOfficeCode, phoneLineCode);

    }


    /**
     * @param areaCode          - 3 digit code
     * @param centralOfficeCode - 3 digit code
     * @param phoneLineCode     - 4 digit code
     * @return a new phone number object
     */ //TODO - if input is valid, return respective PhoneNumber object, else return null

    public static PhoneNumber createPhoneNumberSafely(int areaCode, int centralOfficeCode, int phoneLineCode)
    {
        String phoneNumberstr = "(" + areaCode + ")-" + centralOfficeCode + "-" + phoneLineCode ;
        try {
            PhoneNumber phoneNumber = createPhoneNumber(phoneNumberstr);
            return phoneNumber;

        } catch (InvalidPhoneNumberFormatException ipnfe)
        {
            logger.warning("Invalid Phone number was entered");
            return null;
        }
    }

    /**
     * @param phoneNumberString - some String corresponding to a phone number whose format is `(###)-###-####`
     * @return a new phone number object
     * @throws InvalidPhoneNumberFormatException - thrown if phoneNumberString does not match acceptable format
     */ // TODO - Add throws statement to method signature

    public static PhoneNumber createPhoneNumber(String phoneNumberString) throws InvalidPhoneNumberFormatException
    {
        PhoneNumber number = null;
        number = new PhoneNumber(phoneNumberString);
        logger.info(" Attempting to create a new PhoneNumber object with a value of " + number);

        return number;
    }
}
